open_petro_elastic
==================

open_petro_elastic is a commandline tool and python
library for petro elastic modelling and fluid
substitution.

Basic usage is::

    open_petro_elastic config.yaml

See the confige file section for further information
about the contents of config.yaml. You can also
generate a tutorial config by running::

    open_petro_elastic --generate-tutorial


.. toctree::
    :maxdepth: 1

    command_line_options
    config_file_format
    usage_as_a_library


Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
